package com.zhyc.module.produce.other.service;

import java.util.List;

import com.zhyc.module.produce.other.domain.ScFixHoof;

/**
 * 修蹄Service接口
 *
 * @author ruoyi
 * @date 2025-07-10
 */
public interface IScFixHoofService {
    /**
     * 查询修蹄
     *
     * @param id 修蹄主键
     * @return 修蹄
     */
    public ScFixHoof selectScFixHoofById(Integer id);

    /**
     * 查询修蹄列表
     *
     * @param scFixHoof 修蹄
     * @return 修蹄集合
     */
    public List<ScFixHoof> selectScFixHoofList(ScFixHoof scFixHoof);

    /**
     * 新增修蹄
     *
     * @param scFixHoof 修蹄
     * @return 结果
     */
    public int insertScFixHoof(ScFixHoof scFixHoof);

    /**
     * 修改修蹄
     *
     * @param scFixHoof 修蹄
     * @return 结果
     */
    public int updateScFixHoof(ScFixHoof scFixHoof);

    /**
     * 批量删除修蹄
     *
     * @param ids 需要删除的修蹄主键集合
     * @return 结果
     */
    public int deleteScFixHoofByIds(Integer[] ids);

    /**
     * 删除修蹄信息
     *
     * @param id 修蹄主键
     * @return 结果
     */
    public int deleteScFixHoofById(Integer id);

    /**
     * 根据管理耳号查询
     *
     * @param manageTags
     * @return
     */
    Long findIdByManageTags(String manageTags);

    List<String> searchEarNumbers(String query);
}
